package com.mdd.admin.controller.system;

import com.alibaba.fastjson2.JSONObject;
import com.mdd.admin.LikeAdminThreadLocal;
import com.mdd.admin.aop.Log;
import com.mdd.admin.service.ISystemAuthAdminService;
import com.mdd.admin.validate.commons.IdValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.system.SystemAdminCreateValidate;
import com.mdd.admin.validate.system.SystemAdminSearchValidate;
import com.mdd.admin.validate.system.SystemAdminUpInfoValidate;
import com.mdd.admin.validate.system.SystemAdminUpdateValidate;
import com.mdd.admin.validate.user.UserLogoutValidate;
import com.mdd.admin.vo.system.SystemAuthAdminDetailVo;
import com.mdd.admin.vo.system.SystemAuthAdminListedVo;
import com.mdd.admin.vo.system.SystemAuthAdminSelvesVo;
import com.mdd.common.aop.NotLogin;
import com.mdd.common.aop.NotPower;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import com.mdd.common.validator.annotation.IDMust;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"api/system/admin"})
@Api(
   tags = {"系统用户管理"}
)
public class SystemAuthAdminController {
   @Resource
   ISystemAuthAdminService iSystemAuthAdminService;

   @NotPower
   @GetMapping({"/ding"})
   @ApiOperation("保持在线")
   public AjaxResult<?> ding() {
      return AjaxResult.success();
   }

   @GetMapping({"/list"})
   @ApiOperation("管理员列表")
   public AjaxResult<PageResult<SystemAuthAdminListedVo>> list(@Validated PageValidate pageValidate, @Validated SystemAdminSearchValidate searchValidate) {
      PageResult<SystemAuthAdminListedVo> list = this.iSystemAuthAdminService.list(pageValidate, searchValidate);
      return AjaxResult.success(list);
   }

   @NotPower
   @GetMapping({"/self"})
   @ApiOperation("管理员信息")
   public AjaxResult<SystemAuthAdminSelvesVo> self() {
      Integer adminId = LikeAdminThreadLocal.getAdminId();
      SystemAuthAdminSelvesVo vo = this.iSystemAuthAdminService.self(adminId);
      return AjaxResult.success(vo);
   }

   @GetMapping({"/detail"})
   @ApiOperation("管理员详情")
   public AjaxResult<SystemAuthAdminDetailVo> detail(@Validated @IDMust @RequestParam("id") Integer id) {
      SystemAuthAdminDetailVo vo = this.iSystemAuthAdminService.detail(id);
      return AjaxResult.success(vo);
   }

   @Log(
      title = "管理员新增"
   )
   @PostMapping({"/add"})
   @ApiOperation("管理员新增")
   public AjaxResult<Object> add(@Validated @RequestBody SystemAdminCreateValidate createValidate) {
      this.iSystemAuthAdminService.add(createValidate);
      return AjaxResult.success();
   }

   @Log(
      title = "管理员编辑"
   )
   @PostMapping({"/edit"})
   @ApiOperation("管理员编辑")
   public AjaxResult<Object> edit(@Validated @RequestBody SystemAdminUpdateValidate updateValidate) {
      Integer adminId = LikeAdminThreadLocal.getAdminId();
      this.iSystemAuthAdminService.edit(updateValidate, adminId);
      return AjaxResult.success();
   }

   @Log(
      title = "重置管理员派发数量"
   )
   @PostMapping({"/resetCount"})
   @ApiOperation("重置管理员派发数量")
   public AjaxResult<Object> resetCount(@RequestBody JSONObject json) {
      Integer adminId = json.getInteger("adminId");
      if (adminId != null && adminId > 0) {
         this.iSystemAuthAdminService.resetCount(adminId);
         return AjaxResult.success();
      } else {
         return AjaxResult.failed("管理员ID参数无效");
      }
   }

   @NotPower
   @Log(
      title = "管理员更新"
   )
   @PostMapping({"/upInfo"})
   @ApiOperation("当前管理员更新")
   public AjaxResult<Object> upInfo(@Validated @RequestBody SystemAdminUpInfoValidate upInfoValidate) {
      Integer adminId = LikeAdminThreadLocal.getAdminId();
      this.iSystemAuthAdminService.upInfo(upInfoValidate, adminId);
      return AjaxResult.success();
   }

   @Log(
      title = "管理员删除"
   )
   @PostMapping({"/del"})
   @ApiOperation("管理员删除")
   public AjaxResult<Object> del(@Validated @RequestBody IdValidate idValidate) {
      Integer adminId = LikeAdminThreadLocal.getAdminId();
      this.iSystemAuthAdminService.del(idValidate.getId(), adminId);
      return AjaxResult.success();
   }

   @Log(
      title = "管理员状态"
   )
   @PostMapping({"/disable"})
   @ApiOperation("管理员状态切换")
   public AjaxResult<Object> disable(@Validated @RequestBody IdValidate idValidate) {
      Integer adminId = LikeAdminThreadLocal.getAdminId();
      this.iSystemAuthAdminService.disable(idValidate.getId(), adminId);
      return AjaxResult.success();
   }

   @NotLogin
   @PostMapping({"/logout"})
   @ApiOperation("踢出登录商户账号")
   public AjaxResult<Object> logout(@Validated @RequestBody UserLogoutValidate logoutValidate) {
      return this.iSystemAuthAdminService.logout(logoutValidate);
   }
}
